package com.ann.demo.interfaces.impl;


import com.ann.demo.entity.filing.ArchiveMaster;
import com.ann.demo.interfaces.HomepageDictionary;
import com.ann.demo.service.ArchiveDetailService;
import com.ann.demo.service.ArchiveMasterService;
import com.ann.demo.util.ExceptionPrintUtil;
import com.google.common.base.Objects;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;

import javax.jws.WebService;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

/**
 * @Author: LeiJiaXin
 * @Date: 2019/6/11 17:01
 */

@WebService(serviceName = "HomepageDictionary", // 与接口中指定的name一致
        targetNamespace = "http://interfaces.demo.ann.com/", // 与接口中的命名空间一致,一般是接口的包名倒
        endpointInterface = "com.ann.demo.interfaces.HomepageDictionary"// 接口地址
)
public class HomepageDictionaryImpl implements HomepageDictionary {

    private static final Logger logger = LoggerFactory.getLogger(HomepageDictionaryImpl.class);

    @Autowired
    private ArchiveDetailService archiveDetailService;

    @Autowired
    private ArchiveMasterService archiveMasterService;

    // pdf地址
    public static String mustCheckData;

    @Value("${mustCheckData}")
    public void setMustCheckData(String mustCheckData) {
        HomepageDictionaryImpl.mustCheckData = mustCheckData;
    }

    public static String getMustCheckData() {
        return mustCheckData;
    }


    // 检验申请单号
    public static String inspectionReportType;
    @Value("${inspectionReportType}")
    public void setInspectionReportType(String inspectionReportType) {
        HomepageDictionaryImpl.inspectionReportType = inspectionReportType;
    }

    // 检查申请单号
    public static String checkReportType;
    @Value("${checkReportType}")
    public void setCheckReportType(String checkReportType) {
        HomepageDictionaryImpl.checkReportType = checkReportType;
    }

    @Override
    public String CheckData(String masterId) {
        StringBuffer sb = new StringBuffer();
        try{
            ArchiveMaster archiveMaster = archiveMasterService.findByIdAndIsValid(masterId);
            if (archiveMaster == null){
                return  "没有该患者信息！";
            }
            // 必须检查类型
            sb = new StringBuffer();
            String[] inspectionReportTypeArray;
            List types;
            String checkLisNotExits;
            if (!mustCheckData.equals("")) {
                inspectionReportTypeArray = mustCheckData.split(",");
                types = Arrays.asList(inspectionReportTypeArray);
                checkLisNotExits = this.archiveDetailService.getTypeNotExits(types, masterId);
                if (checkLisNotExits != null) {
                    sb.append("缺失" + checkLisNotExits);
                }

                //----------------单独处理出院记录，包含情况 2021-1-14
                //----------------如果缺失出院记录，那么考虑是不是24小时病历，如果是，那么提示不缺失，如果不是， 那么考虑是不是存在die病历，如果是，那么提示，缺失死亡记录，否择提示缺失出院记录；
                List list = new ArrayList();
                list.add("11");
                String disResult = archiveDetailService.getTypeNotExits(list, masterId);
                if (disResult != null ) {
                    //再判断是不是24小时入院
                    String beHospitalized = archiveDetailService.getBeHospitalized(masterId, "9");
                    if (!Objects.equal(beHospitalized, "24小时内入出院记录")) {
                            sb.append("，" + disResult);
                    }
                }
                List list1 = new ArrayList();
                list1.add("113");
                String disResult1 = archiveDetailService.getTypeNotExits(list1, masterId);
                if (disResult1 != null ) {
                    //再判断是不是24小时入院
                    String beHospitalized1 = archiveDetailService.getBeHospitalized(masterId, "9");
                    if (!Objects.equal(beHospitalized1, "24小时内入出院记录")) {
                        if (Objects.equal(archiveMaster.getDeathFlag(), "1")) {
                            Integer dieResult1 = archiveDetailService.countDetail(masterId, "17");
                            if(dieResult1 == 0){
                                sb.append("，死亡记录");
                            }
                        }else{
                            sb.append("，" + disResult1);
                        }
                    }
                }
                //单独检验骨密度
                List list2 = new ArrayList();
                list1.add("130");
                String disResult2 = archiveDetailService.getTypeNotExits(list2, masterId);
                if (disResult2==null){
                    int dicomNum = archiveDetailService.getDicomNum(masterId);
                    if (dicomNum>0){
                        if (sb.length()==0){
                            sb.append("缺失骨密度检查报告");
                        }else {
                            sb.append("，"+"缺失骨密度检查报告");
                        }

                    }
                }
            }

            // 检验申请单
            if (!inspectionReportType.equals("")) {
                inspectionReportTypeArray = inspectionReportType.split(",");
                types = Arrays.asList(inspectionReportTypeArray);
                checkLisNotExits = this.archiveDetailService.getInspectionReportNotExits1(types, masterId);
                if (checkLisNotExits != null) {
                    if (sb.length() != 0) {
                        sb.append(";");
                    }

                    sb.append(checkLisNotExits);
                }
            }
            if (sb.length() == 0) {
                sb.append("完整");
            }else{
                sb.append("。如开的医嘱有对应的单子，可备注给主任。");
            }

        }catch (Exception e){
            sb.setLength(0);
            sb.append("服务器正忙");
            ExceptionPrintUtil.printException(e);
            logger.error("出错了：",e.getMessage());
        }
        return sb + "";
    }
}
