package com.ann.demo.service.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.ann.demo.entity.filing.*;
import com.ann.demo.repository.MedicalRecordHomepageCacheRepository;
import com.ann.demo.service.ArchiveMasterService;
import com.ann.demo.service.MedicalRecordHomepageCacheService;
import org.junit.platform.commons.util.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * @Author: LeiJiaXin
 * @Date: 2019/9/26 9:27
 */
@Service
public class MedicalRecordHomepageCacheServiceImpl implements MedicalRecordHomepageCacheService {

    public static final int min = 5;
    public static final int max = 1000000;
    public static final int day = 28;
    public static final int yearDay = 365;
    static final Logger logger = LoggerFactory.getLogger(MedicalRecordHomepageCacheServiceImpl.class);

    @Autowired
    MedicalRecordHomepageCacheRepository medicalRecordHomepageCacheRepository;

    @Override
    public String handleMedicalRecordHomepageCache(String masterId) {
        masterId = "82533508-f706-49bc-bc62-20cb4f5c647f";
        MedicalRecordHomepageCache mc = medicalRecordHomepageCacheRepository.findByMasterId(masterId);
        if (null != mc) {
            StringBuffer stringBuffer = new StringBuffer();
            String content = mc.getContent();
            if (StringUtils.isNotBlank(content)) {
                //获取校验规则的结果
                stringBuffer.append(ValidationRules(content));
                return content;
            }
        }
        return null;
    }

    /**
     * 规则校验
     *
     * @param content
     * @return
     */
    private StringBuffer ValidationRules(String content) {
        MedicalRecordHomepage mr = JSONObject.parseObject(content, MedicalRecordHomepage.class);
        CommonTable commonTable = mr.getCommonTable();
        CommonTable1 commonTable1 = mr.getCommonTable1();
        List<OperDetail> operDetails = mr.getOperDetails();
        List<DiagDetail> diagDetails = mr.getDiagDetails();
        OtherData otherData = mr.getOtherData();
        StringBuffer stringBuffer = new StringBuffer();
        ContentRetrunInfo contentRetrunInfo = new ContentRetrunInfo();
        /**
         * 新生儿出生体重（可能多胎）
         */
        if (YZY072(commonTable, commonTable1, diagDetails)) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY072"));
        }

        /**
         * 新生儿入院体重
         */
        if (YZY073(commonTable, commonTable1)) {
            if (0 == commonTable1.getYZY072()) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY073"));
            }
        }

        /**
         * 病案号
         */
        if (StringUtils.isBlank(commonTable.getYZY001())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY001"));
        }

        /**
         * 年龄-1
         */
        if (StringUtils.isBlank(commonTable.getAKC023())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC023", 1));
        }

        /**
         * 年龄-2
         */
        if (getBetweenDays(commonTable1.getAAC006(), commonTable.getYKC701()) / yearDay < commonTable.getAge() - 1 || getBetweenDays(commonTable1.getAAC006(), commonTable.getYKC701()) / yearDay > commonTable.getAge() + 1) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC023", 2));
        }

        /**
         * 不足一周岁年龄（月天）-1
         */
        if (AKC023(commonTable1, diagDetails)) {
            if (getBetweenDays(commonTable1.getAAC006(), commonTable.getYKC701()) > day && !(commonTable.getAge() == 0 && commonTable.getAge_day() <= day)) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC023", 3));
            }
        }

        /**
         * 不足一周岁年龄（月天）-2
         */
        if (commonTable.getAge() == 0 && StringUtils.isBlank(commonTable.getAKC023())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC023", 4));
        }


        /**
         * 出生日期
         */
        if (null == commonTable1.getAAC006()) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AAC006"));
        }

        /**
         * 性别-1
         */
        if (StringUtils.isBlank(commonTable.getYZY008())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY008", 1));
        }

        /**
         * 性别-2
         */
        if ("男".equals(commonTable.getYZY008())) {
            if (YZY008Male(commonTable1, diagDetails)) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY008", 2));
            }
        }

        /**
         * 性别-3
         */
        if ("女".equals(commonTable.getYZY008())) {
            if (YZY008Female(commonTable1, diagDetails)) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY008", 3));
            }
        }

        /**
         * 医疗付费方式
         */
        if (StringUtils.isBlank(commonTable1.getYZY074())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY074"));
        }

        /**
         * 现住址（省、市、县、街道）
         */
        if (StringUtils.isBlank(commonTable.getYZY075())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY075"));
        }

        /**
         * 出生地（省、市、县）
         */
        if (StringUtils.isBlank(commonTable1.getYZY010())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY010"));
        }

        /**
         * 职业
         */
        if (StringUtils.isBlank(commonTable1.getYZY016())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY016"));
        }

        /**
         * 联系人地址
         */
        if (StringUtils.isNotBlank(commonTable1.getAAE004())) {
            if (StringUtils.isBlank(commonTable1.getYZY027())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY027"));
            }
        }

        /**
         * 联系人电话
         */
        if (StringUtils.isNotBlank(commonTable1.getAAE004())) {
            if (StringUtils.isBlank(commonTable1.getYZY028())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY028"));
            }
        }

        /**
         * 身份证
         */
        if (StringUtils.isBlank(commonTable1.getYZY011())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY011"));
        }

        /**
         * 住院次数
         */
        if (StringUtils.isBlank(commonTable.getYZY002())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY002"));
        }

        /**
         * 婚姻
         */
        if (StringUtils.isBlank(commonTable1.getYZY018())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY018"));
        }

        /**
         * 姓名
         */
        if (StringUtils.isBlank(commonTable.getAAC003())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AAC003"));
        }

        /**
         * 民族
         */
        if (StringUtils.isBlank(commonTable1.getYZY015())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY015"));
        }

        /**
         * 国籍
         */
        if (StringUtils.isBlank(commonTable1.getYZY013())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY013"));
        }

        /**
         * 籍贯
         */
        if (StringUtils.isBlank(commonTable1.getYZY076())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY076"));
        }

        /**
         * 组织机构代码
         */
        if (StringUtils.isBlank(otherData.getYZY077())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY077"));
        }

        /**
         * 医疗机构
         */
        if (StringUtils.isBlank(otherData.getYZY078())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY078"));
        }

        /**
         * 户口地址（省、市、县、街道）
         */
        if (StringUtils.isBlank(commonTable1.getAAC010())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AAC010"));
        }

        /**
         * 户口地址邮编
         */
        if (StringUtils.isBlank(otherData.getYZY024())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY024"));
        }

        /**
         * 联系人关系
         */
        if (StringUtils.isNotBlank(commonTable1.getAAE004())) {
            if (StringUtils.isBlank(commonTable1.getYZY026())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY026"));
            }
        }

        /**
         * 户口地址邮编
         */
        if (StringUtils.isBlank(commonTable1.getYZY079())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY079"));
        }

        /**
         * 工作单位电话
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY020())) {
            if (StringUtils.isBlank(commonTable1.getYZY021())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY021"));
            }
        }

        /**
         * 工作单位地址邮编
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY020())) {
            if (StringUtils.isBlank(commonTable1.getYZY022())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY022"));
            }
        }

        /**
         * 现住址邮编
         */
        if (StringUtils.isBlank(commonTable1.getYZY080())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY080"));
        }

        /**
         * 住院总费用 1
         */
        if (StringUtils.isBlank(commonTable1.getAKC264())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC264", 1));
        }

        /**
         * 住院总费用 2
         */
        if (Double.valueOf(commonTable1.getAKC264()) <= min || Double.valueOf(commonTable1.getAKC264()) >= max) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC264", 2));
        }

        /**
         * 治疗类-9-临床物理治疗费
         */
        if (Double.valueOf(commonTable1.getYZY132()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY132"));
        }

        /**
         * 治疗类-10-麻醉费
         */
        if (Double.valueOf(commonTable1.getYZY134()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY134"));
        }

        /**
         * 西药类-13-抗菌药物费用
         */
        if (Double.valueOf(commonTable1.getYZY152()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY152"));
        }

        /**
         * 综合医疗服务类-一般医疗服务费(1)
         */
        if (Double.valueOf(commonTable1.getYZY123()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY123"));
        }

        /**
         * 综合医疗服务类-一般治疗操作费(2)
         */
        if (Double.valueOf(commonTable1.getYZY124()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY124"));
        }

        /**
         * 综合医疗服务类-护理费(3)
         */
        if (Double.valueOf(commonTable1.getYZY125()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY125"));
        }

        /**
         * 综合医疗服务类-其他费用(4)
         */
        if (Double.valueOf(commonTable1.getYZY126()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY126"));
        }

        /**
         * 诊断类-病理诊断费(5) 1
         */
        if (Double.valueOf(commonTable1.getYZY127()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY127", 1));
        }

        /**
         * 基于其他病理诊断内容判断诊断类-病理诊断费(5)不为空
         */
        List<String> tumourList = Arrays.asList("C00", "C01", "C02", "C03", "C04", "C05", "C06", "C07", "C08", "C09", "C10", "C11", "C12",
                "C13", "C14", "C15", "C16", "C17", "C18", "C19", "C20", "C21", "C22", "C23", "C24", "C25", "C26", "C27", "C28", "C29", "C30",
                "C31", "C32", "C33", "C34", "C35", "C36", "C37", "C38", "C39", "C40", "C41", "C42", "C43", "C44", "C45", "C46", "C47", "C48",
                "C49", "C50", "C51", "C52", "C53", "C54", "C55", "C56", "C57", "C58", "C59", "C60", "C61", "C62", "C63", "C64", "C65", "C66",
                "C67", "C68", "C69", "C70", "C71", "C72", "C73", "C74", "C75", "C76", "C77", "C78", "C79", "C80", "C81", "C82", "C83", "C84",
                "C85", "C86", "C87", "C88", "C89", "C90", "C91", "C92", "C93", "C94", "C95", "C96", "C97", "D00", "D01", "D02", "D03", "D04",
                "D05", "D06", "D07", "D08", "D09", "D10", "D11", "D12", "D13", "D14", "D15", "D16", "D17", "D18", "D19", "D20", "D21", "D22",
                "D23", "D24", "D25", "D26", "D27", "D28", "D29", "D30", "D31", "D32", "D33", "D34", "D35", "D36", "D37", "D38", "D39", "D40",
                "D41", "D42", "D43", "D44", "D45", "D46", "D47", "D48");
        if (YZY127(diagDetails, otherData, tumourList)) {
            if (StringUtils.isBlank(commonTable1.getYZY127())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY127", 2));
            }
        }

        /**
         * 诊断类-实验室诊断费(6)
         */
        if (StringUtils.isBlank(commonTable1.getYZY128())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY128"));
        }

        /**
         * 诊断类-影像学诊断费(7)
         */
        if (StringUtils.isBlank(commonTable1.getYZY129())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY129"));
        }

        /**
         * 治疗类-非手术治疗项目费(9) 1
         */
        if (Double.valueOf(commonTable1.getYZY131()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY131", 1));
        }

        /**
         * 治疗类-非手术治疗项目费(9) 2
         */
        if (Double.valueOf(commonTable1.getYZY131()) < Double.valueOf(commonTable1.getYZY132())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY131", 2));
        }

        /**
         * 治疗类-手术治疗费(10) 1
         */
        if (Double.valueOf(otherData.getYZY133()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY133", 1));
        }

        /**
         * 治疗类-手术治疗费(10) 2
         */
        if (Double.valueOf(otherData.getYZY133()) < Double.valueOf(commonTable1.getYZY134()) + Double.valueOf(commonTable1.getYZY135())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY133", 2));
        }

        /**
         * 治疗类-手术治疗费(10) 3
         */
        if ("有".equals(commonTable.getIsOper()) && StringUtils.isBlank(otherData.getYZY133())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY133", 3));
        }

        /**
         * 康复类-康复费(11)
         */
        if (Double.valueOf(commonTable1.getYZY136()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY136"));
        }

        /**
         * 中医类-中医治疗费(12)
         */
        if (Double.valueOf(commonTable1.getYZY137()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY137"));
        }

        /**
         * 西药类-西药费(13)-1
         */
        if (Double.valueOf(commonTable1.getYZY138()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY138", 1));
        }

        /**
         * 西药类-西药费(13)-2
         */
        if (Double.valueOf(commonTable1.getYZY138()) < Double.valueOf(commonTable1.getYZY152())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY138", 2));
        }

        /**
         * 中药类-中成药费(14)
         */
        if (Double.valueOf(commonTable1.getYZY153()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY153"));
        }

        /**
         * 中药类-中草药费(15)
         */
        if (Double.valueOf(commonTable1.getYZY154()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY154"));
        }

        /**
         * 血液和血液制品类-血费(16)
         */
        if (Double.valueOf(commonTable1.getYZY139()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY139"));
        }

        /**
         * 血液和血液制品类-白蛋白类制品费(17)
         */
        if (Double.valueOf(commonTable1.getYZY140()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY140"));
        }

        /**
         * 血液和血液制品类-球蛋白类制品费(18)
         */
        if (Double.valueOf(commonTable1.getYZY141()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY141"));
        }

        /**
         * 血液和血液制品类-凝血因子类制品费(19)
         */
        if (Double.valueOf(commonTable1.getYZY142()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY142"));
        }

        /**
         * 血液和血液制品类-细胞因子类制品费(20)
         */
        if (Double.valueOf(commonTable1.getYZY143()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY143"));
        }

        /**
         * 耗材类-检查用一次性医用材料费(21)
         */
        if (Double.valueOf(commonTable1.getYZY144()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY144"));
        }

        /**
         * 耗材类-治疗用一次性医用材料费(22)
         */
        if (Double.valueOf(commonTable1.getYZY145()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY145"));
        }

        /**
         * 耗材类-手术用一次性医用材料费(23)
         */
        if (Double.valueOf(commonTable1.getYZY146()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY146"));
        }

        /**
         * 其他类-其他费(24)
         */
        if (Double.valueOf(commonTable1.getYZY155()) < 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY155"));
        }

        /**
         * 自付费用
         */
        if (StringUtils.isBlank(commonTable1.getYZY122())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY122"));
        }

        /**
         * （主要出院诊断）编码
         */
        List<String> mainList = Arrays.asList("V", "W", "X", "Y");
        if (mainList.contains(commonTable.getMainDiagCode().substring(0, 1))) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("mainDiagCode"));
        }

        /**
         * （主要出院诊断）名称
         */
        if (StringUtils.isBlank(commonTable.getMainDiagName())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("mainDiagName"));
        }

        /**
         * （主要手术）名称
         */
        if (StringUtils.isNotBlank(otherData.getYZY133()) && StringUtils.isBlank(otherData.getYZY105())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY105"));
        }

        /**
         * （主要操作）名称
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY129()) && StringUtils.isBlank(otherData.getYZY110())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY110"));
        }

        /**
         * （其他出院诊断）编码-1
         */
        if (mainList.contains(otherData.getYZY221().substring(0, 1))) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY221", 1));
        }

        /**
         * （其他出院诊断）编码-2
         */
        if (YZY221(diagDetails)) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY221", 2));
        }

        /**
         * Z37不能作为组长
         */
        if (AKC196(diagDetails)) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC196", 1));
        }

        /**
         * 主要诊断出现C00到C97 D00到D48 附属诊断开头为N 且有斜杆
         */
        if (AKC196(diagDetails, tumourList)) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("AKC196", 2));
        }


        /**
         * （主要出院诊断）入院病情
         */
        if (StringUtils.isBlank(commonTable1.getYZY111())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY111"));
        }

        /**
         * （入院前）颅脑损伤时间
         */
        if (StringUtils.isBlank(commonTable1.getYZY081())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY081"));
        }

        /**
         * （入院后）颅脑损伤时间
         */
        if (StringUtils.isBlank(commonTable1.getYZY082())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY082"));
        }

        /**
         * （主要操作）切口愈合等级
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY129()) && StringUtils.isBlank(otherData.getYZY083())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY083"));
        }

        /**
         * （主要手术）切口愈合等级
         */
        if (StringUtils.isNotBlank(otherData.getYZY133()) && StringUtils.isBlank(otherData.getYZY084())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY084"));
        }

        /**
         * （主要手术）日期
         */
        if (StringUtils.isNotBlank(otherData.getYZY133()) && StringUtils.isBlank(otherData.getYZY106())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY106"));
        }

        /**
         * （主要操作）日期
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY129()) && StringUtils.isBlank(otherData.getYZY085())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY085"));
        }

        /**
         * 基于其他病理诊断内容判断病理诊断编码不为空
         */
        if (pathologyDingCode(commonTable1, diagDetails, tumourList, otherData)) {
            if (StringUtils.isBlank(otherData.getPathologyDingCode())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("pathologyDingCode"));
            }
        }

        /**
         * 基于其他病理诊断内容判断病理诊断不为空
         */
        if (pathologyDingCode(commonTable1, diagDetails, tumourList, otherData)) {
            if (StringUtils.isBlank(otherData.getPathologyDingName())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("pathologyDingName"));
            }
        }

        /**
         * （主要手术）麻醉方式
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY134()) && StringUtils.isBlank(otherData.getYZY107())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY107"));
        }

        /**
         * 门急诊诊断编码
         */
        if (mainList.contains(commonTable1.getYZY113().substring(0, 1))) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY113"));
        }

        /**
         * 门急诊诊断
         */
        if (StringUtils.isBlank(commonTable1.getYZY114())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY114"));
        }

        /**
         * 过敏药物
         */
        if (StringUtils.isNotBlank(commonTable1.getIs_medicine()) && StringUtils.isBlank(commonTable1.getYZY046())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY046"));
        }

        /**
         * 死亡患者是否尸检
         */
        if ("死亡".equals(commonTable1.getYZY070()) && StringUtils.isBlank(commonTable1.getYZY089())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY089"));
        }

        /**
         * ABO血型
         */
        if (StringUtils.isBlank(commonTable1.getYZY090())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY090"));
        }

        /**
         * 有无药物过敏
         */
        if (StringUtils.isBlank(commonTable1.getIs_medicine())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("is_medicine"));
        }

        /**
         * 损伤、中毒的外部原因疾病编码必填
         */
        if ("S".equals(commonTable.getMainDiagCode().substring(0, 1)) || "T".equals(commonTable.getMainDiagCode().substring(0, 1))) {
            if (StringUtils.isBlank(otherData.getYZY091())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY091"));
            }
        }

        /**
         * 损伤中毒的外部原因编码
         */
        if (YZY092(diagDetails, mainList)) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY092"));
        }

        /**
         * 损伤、中毒的外部原因必填
         */
        if ("S".equals(commonTable.getMainDiagCode().substring(0, 1)) || "T".equals(commonTable.getMainDiagCode().substring(0, 1))) {
            if (StringUtils.isBlank(otherData.getYZY093())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY093"));
            }
        }

        /**
         * （主要操作）级别
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY129()) && StringUtils.isBlank(otherData.getYZY094())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY094"));
        }

        /**
         * （主要手术）级别
         */
        if (StringUtils.isNotBlank(otherData.getYZY133()) && StringUtils.isBlank(otherData.getYZY108())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY108"));
        }

        /**
         * 基于其他病理诊断内容判断病理号不为空
         */
        if (YZY095(commonTable1, diagDetails, tumourList, otherData)) {
            if (StringUtils.isBlank(otherData.getYZY095())) {
                stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY095"));
            }
        }

        /**
         * Rh血型
         */
        if (StringUtils.isBlank(commonTable1.getYZY096())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY096"));
        }

        /**
         * （主要手术）术者
         */
        if (StringUtils.isNotBlank(otherData.getYZY133()) && StringUtils.isBlank(otherData.getYZY109())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY109"));
        }

        /**
         * （主要操作）术者
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY129()) && StringUtils.isBlank(otherData.getYZY097())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY097"));
        }

        /**
         * 离院方式-1
         */
        if (StringUtils.isBlank(commonTable1.getYZY070())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY070"));
        }

        /**
         * 离院方式-2
         */


        /**
         * 入院时间-1
         */
        if (null == commonTable.getYKC701()) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YKC701", 1));
        }

        /**
         * 入院时间-2
         */
        if (commonTable.getYKC701().compareTo(commonTable.getYKC702()) > 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YKC701", 2));
        }

        /**
         * 入院时间-3
         */
        if (commonTable.getYKC701().getTime() <= Long.valueOf(otherData.getYZY106())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YKC701", 3));
        }

        /**
         * 出院时间-1
         */
        if (null == commonTable.getYKC702()) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YKC702", 1));
        }

        /**
         * 出院时间-2
         */
        if (commonTable.getYKC701().compareTo(commonTable.getYKC702()) > 0) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YKC702", 2));
        }

        /**
         * 出院时间-3
         */
        if (commonTable.getYKC701().getTime() <= Long.valueOf(otherData.getYZY106()) && Long.valueOf(otherData.getYZY106()) <= commonTable.getYKC702().getTime()) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YKC702", 3));
        }


        /**
         * 是否有31天内再次入院计划
         */
        if (StringUtils.isBlank(commonTable1.getYZY098())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY098"));
        }

        /**
         * 31天内再次入院目的
         */
        if (StringUtils.isNotBlank(commonTable1.getYZY098()) && StringUtils.isBlank(commonTable1.getYZY099())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY099"));
        }

        /**
         * 转科科别
         */
        if (commonTable1.getYZY033().equals(commonTable.getYZY038())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY101"));
        }

        /**
         * 主任（副主任）医师
         */
        if (StringUtils.isBlank(commonTable1.getYZY052())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY052"));
        }

        /**
         * 编码员
         */
        if (StringUtils.isBlank(commonTable1.getYZY062())) {
            stringBuffer.append(contentRetrunInfo.getReturnInfo("YZY062"));
        }


        return stringBuffer;
    }

    /**
     * 新生儿出生体重（可能多胎）判断
     *
     * @param commonTable
     * @param commonTable1
     * @param diagDetails
     * @return
     */
    private Boolean YZY072(CommonTable commonTable, CommonTable1 commonTable1, List<DiagDetail> diagDetails) {
        if (commonTable.getAge() == 0 && commonTable.getAge_month() == 0 && commonTable.getAge_day() <= 28) {
            return true;
        }
        if (getBetweenDays(commonTable1.getAAC006(), commonTable.getYKC701()) <= 28) {
            return true;
        }
        for (DiagDetail diagDetail : diagDetails) {
            if (!"3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() != 1 && "Z37".equals(diagDetail.getAKC196().substring(0, 3))) {
                return true;
            }
        }
        return false;
    }

    /**
     * 新生儿入院体重 判断
     *
     * @param commonTable
     * @param commonTable1
     * @return
     */
    private Boolean YZY073(CommonTable commonTable, CommonTable1 commonTable1) {
        if (commonTable.getAge() == 0 && commonTable.getAge_month() == 0 && commonTable.getAge_day() <= 28) {
            return true;
        }
        if (getBetweenDays(commonTable1.getAAC006(), commonTable.getYKC701()) <= 28) {
            return true;
        }
        return false;
    }

    /**
     * 不足一周岁年龄（月天）-1 判断
     *
     * @param commonTable1
     * @param diagDetails
     * @return
     */
    private Boolean AKC023(CommonTable1 commonTable1, List<DiagDetail> diagDetails) {
        //判断区间
        List<String> ageList = Arrays.asList("P10", "P11", "P12", "P13", "P14", "P15");
        //门急诊诊断编码判断
        if (ageList.contains(commonTable1.getYZY113().substring(0, 3))) {
            return true;
        }
        //主要诊断，其他诊断判断
        for (DiagDetail diagDetail : diagDetails) {
            if (ageList.contains(diagDetail.getAKC196().substring(0, 3))) {
                return true;
            }
        }
        return false;
    }

    /**
     * 性别-2 判断
     *
     * @param commonTable1
     * @param diagDetails
     * @return
     */
    private Boolean YZY008Male(CommonTable1 commonTable1, List<DiagDetail> diagDetails) {
        //编码区间
        List<String> maleList1 = Arrays.asList("A34", "C51", "C52", "C53", "C54", "C55", "C56", "C57", "C58", "D06", "D25", "D26", "D27", "D28", "D39", "E28", "F53",
                "N70", "N71", "N72", "N73", "N74", "N75", "N76", "N77", "N78", "N79", "N80", "N81", "N82", "N83", "N84", "N85", "N86", "N87", "N88", "N89", "N90", "N91",
                "N92", "N93", "N94", "N95", "N96", "N97", "N98", "O00", "O01", "O02", "O03", "O04", "O05", "O06", "O07", "O08", "O09", "O10", "O11", "O12", "O13", "O14",
                "O15", "O16", "O17", "O18", "O19", "O20", "O21", "O22", "O23", "O24", "O25", "O26", "O27", "O28", "O29", "O30", "O31", "O32", "O33", "O34", "O35", "O36",
                "O37", "O38", "O39", "O40", "O41", "O42", "O43", "O44", "O45", "O46", "O47", "O48", "O49", "O50", "O51", "O52", "O53", "O54", "O55", "O56", "O57", "O58",
                "O59", "O60", "O61", "O62", "O63", "O64", "O65", "O66", "O67", "O68", "O69", "O70", "O71", "O72", "O73", "O74", "O75", "O76", "O77", "O78", "O79", "O80",
                "O81", "O82", "O83", "O84", "O85", "O86", "O87", "O88", "O89", "O90", "O91", "O92", "O93", "O94", "O95", "O96", "O97", "O98", "O99", "Q50", "Q51", "Q52",
                "R87", "Z32", "Z33", "Z34", "Z35", "Z36", "Z37", "Z39");
        List<String> maleList2 = Arrays.asList("B37.3", "C79.6", "D07.0", "D07.1", "D07.2", "D07.3", "E89.4", "F52.5", "I86.3", "L29.2", "M80.0", "M80.1", "M81.0", "M81.1",
                "M83.0", "N99.2", "N99.3", "P54.6", "S31.4", "S37.4", "S37.5", "S37.6", "T19.2", "T19.3", "T83.3", "Z01.4", "Z12.4", "Z30.1", "Z30.3", "Z30.5", "Z31.1",
                "Z31.2", "Z87.5", "Z97.5");
        //门急诊诊断编码判断
        if (maleList1.contains(commonTable1.getYZY113().substring(0, 3)) || maleList2.contains(commonTable1.getYZY113().substring(0, 5))) {
            return true;
        }
        //主要诊断，其他诊断判断
        for (DiagDetail diagDetail : diagDetails) {
            if (maleList1.contains(diagDetail.getAKC196().substring(0, 3)) || maleList2.contains(diagDetail.getAKC196().substring(0, 5))) {
                return true;
            }
        }
        return false;
    }

    /**
     * 性别-3 判断
     *
     * @param commonTable1
     * @param diagDetails
     * @return
     */
    private Boolean YZY008Female(CommonTable1 commonTable1, List<DiagDetail> diagDetails) {
        //编码区间
        List<String> femaleList1 = Arrays.asList("C60", "C61", "C62", "C63", "D29", "D40", "E29", "N40", "N41", "N42", "N43", "N44", "N45", "N46", "N47", "N48",
                "N49", "N50", "N51", "Q53", "Q54", "Q55", "R86");
        List<String> femaleList2 = Arrays.asList("B26.0", "D07.4", "D07.6", "D17.6", "E89.5", "F52.4", "I86.1", "L29.1", "S31.2", "S31.2", "Z12.5");
        //门急诊诊断编码判断
        if (femaleList1.contains(commonTable1.getYZY113().substring(0, 3)) || femaleList2.contains(commonTable1.getYZY113().substring(0, 5))) {
            return true;
        }
        //主要诊断，其他诊断判断
        for (DiagDetail diagDetail : diagDetails) {
            if (femaleList1.contains(diagDetail.getAKC196().substring(0, 3)) || femaleList2.contains(diagDetail.getAKC196().substring(0, 5))) {
                return true;
            }
        }
        return false;
    }

    /**
     * （其他出院诊断）编码-2 判断
     *
     * @param diagDetails
     * @return
     */
    private Boolean YZY221(List<DiagDetail> diagDetails) {
        //编码区间
        List<String> codeList1 = Arrays.asList("O80", "O81", "O82", "O83", "O84");
        List<String> codeList2 = Arrays.asList("O00", "O01", "O02", "O03", "O04", "O05", "O06", "O07", "O08");
        //主要诊断，其他诊断判断
        for (DiagDetail diagDetail : diagDetails) {
            if (codeList1.contains(diagDetail.getAKC196().substring(0, 3))) {
                if (!"3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() != 1 && codeList2.contains(diagDetail.getAKC196().substring(0, 3))) {
                    for (DiagDetail diagDetail2 : diagDetails) {
                        if ("Z37".equals(diagDetail2.getAKC196().substring(0, 3))) {
                            return true;
                        }
                    }
                }
            }
        }
        return false;
    }

    /**
     * 当主要诊断编码的范围在 S00 到 T98 之间时，其他诊断编码的必须为V, W, X, Y开头
     * @param diagDetails
     * @param mainList
     * @return
     */
    private Boolean YZY092(List<DiagDetail> diagDetails, List<String> mainList) {
        List<String> codeList = new ArrayList<String>();
        for (int i = 0; i < 100; i++) {
            if (i >= 0 && i <= 9) {
                codeList.add("D0" + i);
            } else {
                codeList.add("D" + i);
            }
        }
        for (int j = 0; j < 99; j++) {
            if (j >= 0 && j <= 9) {
                codeList.add("T0" + j);
            } else {
                codeList.add("T" + j);
            }
        }
        for (DiagDetail diagDetail : diagDetails) {
            if ("3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() == 1 && codeList.contains(diagDetail.getAKC196().substring(0, 3))) {
                for (DiagDetail diagDetail2 : diagDetails) {
                    if (!"3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() != 1 && !mainList.contains(diagDetail.getAKC196().substring(0, 3))) {
                        return true;
                    }
                }
            }
        }
        return false;
    }

    /**
     * Z37不能作为组长
     *
     * @param diagDetails
     * @return
     */
    private Boolean AKC196(List<DiagDetail> diagDetails) {
        for (DiagDetail diagDetail : diagDetails) {
            if ("3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() == 1 && "Z37".equals(diagDetail.getAKC196().substring(0, 3))) {
                return true;
            }
        }
        return false;
    }

    /**
     * 主要诊断出现C00到C97 D00到D48 附属诊断开头为N 且有斜杆
     *
     * @param diagDetails
     * @return
     */
    private Boolean AKC196(List<DiagDetail> diagDetails, List<String> tumourList) {
        for (DiagDetail diagDetail : diagDetails) {
            if ("3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() == 1 && tumourList.contains(diagDetail.getAKC196().substring(0, 3))) {
                for (DiagDetail diagDetail1 : diagDetails) {
                    if (!"3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() != 1 && !tumourList.contains(diagDetail.getAKC196().substring(0, 1))) {

                    }
                }
            }
        }
        return false;
    }

    /**
     * 基于其他病理诊断内容判断诊断类-病理诊断费(5)不为空 判断
     * @param diagDetails
     * @param otherData
     * @param tumourList
     * @return
     */
    private Boolean YZY127(List<DiagDetail> diagDetails, OtherData otherData, List<String> tumourList){
        for (DiagDetail diagDetail : diagDetails) {
            if ("3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() == 1 && tumourList.contains(diagDetail.getAKC196().substring(0, 3))) {
                if (StringUtils.isNotBlank(otherData.getYZY095()) || StringUtils.isNotBlank(otherData.getPathologyDingCode()) || StringUtils.isNotBlank(otherData.getPathologyDingName())) {
                    return true;
                }
            }
        }
        return false;
    }

    /**
     * 基于其他病理诊断内容判断病理诊断编码不为空 判断
     * @param commonTable1
     * @param diagDetails
     * @param tumourList
     * @param otherData
     * @return
     */
    private Boolean pathologyDingCode(CommonTable1 commonTable1, List<DiagDetail> diagDetails, List<String> tumourList, OtherData otherData) {
        for (DiagDetail diagDetail : diagDetails) {
            if ("3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() == 1 && tumourList.contains(diagDetail.getAKC196().substring(0, 3))) {
                if (StringUtils.isNotBlank(otherData.getYZY095()) || StringUtils.isNotBlank(otherData.getPathologyDingName()) || StringUtils.isNotBlank(commonTable1.getYZY127())) {
                    return true;
                }
            }
        }
        return false;
    }

    /**
     * 基于其他病理诊断内容判断病理号不为空 判断
     * @param commonTable1
     * @param diagDetails
     * @param tumourList
     * @param otherData
     * @return
     */
    private Boolean YZY095(CommonTable1 commonTable1, List<DiagDetail> diagDetails, List<String> tumourList, OtherData otherData){
        for (DiagDetail diagDetail : diagDetails) {
            if ("3".equals(diagDetail.getYZY203()) && diagDetail.getYZY201() == 1 && tumourList.contains(diagDetail.getAKC196().substring(0, 3))) {
                if (StringUtils.isNotBlank(otherData.getPathologyDingName()) || StringUtils.isNotBlank(otherData.getPathologyDingCode()) || StringUtils.isNotBlank(commonTable1.getYZY127())) {
                    return true;
                }
            }
        }
        return false;
    }

    /**
     * 判断两个日期之间天数天数
     *
     * @param startTime
     * @param endTime
     * @return
     */
    private int getBetweenDays(Date startTime, Date endTime) {
        int betweenDays = 0;

        long start = startTime.getTime();
        long end = endTime.getTime();

        betweenDays = (int) (Math.abs(end - start) / (24 * 3600 * 1000));
        return betweenDays;
    }


}
